// Copyright (c) The nextest Contributors
// SPDX-License-Identifier: MIT OR Apache-2.0

//! Integration tests for nextest-runner.

mod fixtures;
mod target_runner;
mod target_triple;
